@@ -3,7 +3,7 @@ from __future__ import annotations
 import json
 import logging
 from pathlib import Path
-from typing import Any, Dict
+from typing import Any
 
 import click
 from pyshark import FileCapture  # type: ignore
@@ -11,11 +11,11 @@ from pyshark.capture.live_capture import LiveCapture, UnknownInterfaceException
 from pyshark.packet.packet import Packet  # type: ignore
 
 from roborock import RoborockException
-from roborock.api import RoborockApiClient
-from roborock.cloud_api import RoborockMqttClient
 from roborock.containers import DeviceData, LoginData
 from roborock.protocol import MessageParser
 from roborock.util import run_sync
+from roborock.version_1_apis.roborock_mqtt_client_v1 import RoborockMqttClientV1
+from roborock.web_api import RoborockApiClient
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -29,7 +29,7 @@ class RoborockContext:
 
     def reload(self):
         if self.roborock_file.is_file():
-            with open(self.roborock_file, "r") as f:
+            with open(self.roborock_file) as f:
                 data = json.load(f)
                 if data:
                     self._login_data = LoginData.from_dict(data)
@@ -54,7 +54,7 @@ class RoborockContext:
 @click.group()
 @click.pass_context
 def cli(ctx, debug: int):
-    logging_config: Dict[str, Any] = {"level": logging.DEBUG if debug > 0 else logging.INFO}
+    logging_config: dict[str, Any] = {"level": logging.DEBUG if debug > 0 else logging.INFO}
     logging.basicConfig(**logging_config)  # type: ignore
     ctx.obj = RoborockContext()
 
@@ -135,9 +135,9 @@ async def command(ctx, cmd, device_id, params):
     if model is None:
         raise RoborockException(f"Could not find model for device {device.name}")
     device_info = DeviceData(device=device, model=model)
-    mqtt_client = RoborockMqttClient(login_data.user_data, device_info)
+    mqtt_client = RoborockMqttClientV1(login_data.user_data, device_info)
     await mqtt_client.send_command(cmd, json.loads(params) if params is not None else None)
-    mqtt_client.__del__()
+    await mqtt_client.async_release()
 
 
 @click.command()
@@ -153,7 +153,7 @@ async def parser(_, local_key, device_ip, file):
     else:
         _LOGGER.info("Listen for interface rvi0 since no file was provided")
         capture = LiveCapture(interface="rvi0")
-    buffer = {"data": bytes()}
+    buffer = {"data": b""}
 
     def on_package(packet: Packet):
         if hasattr(packet, "ip"):
